@@ -3,7 +3,7 @@ with open("README.md", "r", encoding="utf-8") as fh:
     long_description = fh.read()
 setuptools.setup(
     name="filez_MagmaMc",
-    version="0.1.0",
+    version="1.0.1",
     author="MagmaMc",
     author_email="kaicycle11@gmail.com",
     description="read, write, scan in json",
@@ -14,7 +14,10 @@ setuptools.setup(
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
+    install_requires=[
+          'tkinter',
+      ],
     package_dir={"": "src"},
     packages=setuptools.find_packages(where="src"),
-    python_requires=">=3.6",
+    python_requires=">=3.7",
 )
\ No newline at end of file
